import { CssClassList } from '../../utilities/css';
import { colours } from '../../css/colours/css';
import { btn } from '../../css/buttons/css';

export interface IButtonProps {
  /**
   * if set to true, the button will span the full width of it's own container element
   * @type {boolean}
   */
  block?: boolean;
  /**
   * you can add every css class you want
   * @type {string}
   */
  className?: string;
  /**
   * This will add the related css colour class
   * 	available colours:
   * 		black
   *     blue
   *     gray
   *     green
   *     orange
   *     purple
   *     red
   *     white
   *     yellow
   * @type {string}
   */
  color?: string;
  /**
   * if set to true, the button will be hollow
   * @type {boolean}
   */
  hollow?: boolean;
  /**
   * if provided, the css button will have a glyphicon element with the provided className
   * @type {string}
   */
  icon?: string;
  /**
   * the onClick callback event
   * @type {any}
   */
  onClick?: any;
  /**
   * the onTouchEnd callback event
   * @type {any}
   */
  onTouchEnd?: any;
  /**
   * the onTouchStart callback event
   * @type {any}
   */
  onTouchStart?: any;
  /**
   * this will add a btn--rounded css class
   */
  rounded?: boolean;
  /**
   * button's title
   * @type {string}
   */
  title?: string;
}

export class Button extends React.Component<IButtonProps, {}> {
  public render() {
    // let css = 'btn';
    let css = new CssClassList(btn.btn);
    css.add(this.props.className || '');
    css.add(btn[this.props.color || colours.blue]);
    if (this.props.block) css.add(btn.block);
    if (this.props.hollow) css.add(btn.hollow);
    if (this.props.icon) css.add(btn.icon);
    if (this.props.rounded) css.add(btn.rounded);
    return (
      <a
        className={css.toString()}
        onClick={this.props.onClick}
        onTouchEnd={this.props.onTouchEnd}
        onTouchStart={this.props.onTouchStart}
        title={this.props.title}
      >
        {
          this.props.icon ? <i className={`btn__icon ${this.props.icon}`}/> : null
        }
        {this.props.children}
      </a>
    )
  }
}
