import { CssClassList } from '../../utilities/css';
import { card } from '../../css/cards/css';
import { colours } from '../../css/colours/css';

interface ICardHeaderProps {
  color?: string;
  className?: string;
  image?: string;
  tall?: boolean;
}

interface ICardProps {
  afterContent?: any;
  beforeContent?: any;
  color?: string;
  footer?: any;
  hideHeader?: boolean;
  headerClassName?: string;
  headerImage?: string;
  headerTall?: boolean;
  title?: string;
}

export class CardHeader extends React.Component<ICardHeaderProps, {}> {
  public render() {
    let _css = new CssClassList(card.header.header);
    let _style: React.CSSProperties = {};
    _css.add(card.header[this.props.color || colours.blue]);
    _css.add(this.props.className || '');
    if (this.props.tall) _css.add(card.header.tall);
    if (this.props.image) _style.backgroundImage = this.props.image;
    return (
      <header className={_css.toString()} style={_style}>
        {this.props.children}
      </header>
    )
  }
}

export class Card extends React.Component<ICardProps, {}> {
  public static Header = CardHeader;

  public render() {
    return (
      <article className={card.card}>
        {
          !this.props.hideHeader ?
            <CardHeader color={this.props.color} className={this.props.headerClassName} image={this.props.headerImage}>{this.props.title}</CardHeader>
          : null
        }
        {this.props.beforeContent}
        <div className={card.content}>{this.props.children}</div>
        {this.props.afterContent}
        {
          this.props.footer ?
            <footer className={card.footer}>{this.props.footer}</footer>
          : null
        }
      </article>
    )
  }
}
