/// <reference path="../react/react.d.ts"/>

declare module "ride-components-react" {}

declare module "ride-components-react/components" {}

declare module "ride-components-react/components/app" {
  export * from "ride-components-react/components/app";
  export * from "ride-components-react/components/app/aside";
  export * from "ride-components-react/components/app/content";
  export * from "ride-components-react/components/app/title";
  export * from "ride-components-react/components/app/toolbar";
}

declare module "ride-components-react/components/app/app" {
  export interface IAppProperties {
    aside?: any;
    asideColor?: string;
    asideTitle?: string;
    asideTitleColor?: string;
    content?: any;
    contentColor?: string;
    contentTitle?: string;
    contentToolbar?: any;
    contentToolbarColor?: string;
  }

  export class App extends React.Component<IAppProperties, {}> {}
}

declare module "ride-components-react/components/app/aside" {
  export interface IAppAsideProperties {
    color?: string;
    title?: string;
    titleColor?: string;
  }

  export class AppAside extends React.Component<IAppAsideProperties, {}> {}
}

declare module "ride-components-react/components/app/content" {
  export interface IAppContentProperties {
    color?: string;
    title?: string;
    toolbar?: any;
    toolbarColor?: string;
  }

  export class AppContent extends React.Component<IAppContentProperties, {}> {}
}

declare module "ride-components-react/components/app/title" {
  export interface IAppAsideTitleProperties {
    color?: string;
  }

  export class AppAsideTitle extends React.Component<IAppAsideTitleProperties, {}> {}
}

declare module "ride-components-react/components/app/toolbar" {
  export interface IToolbarItemProperties {

  }

  export class ToolbarItem extends React.Component<IToolbarItemProperties, any> {}
}

declare module "ride-components-react/components/baloons/baloon" {
  export interface IBaloonProps {
    /**
     * additional css classes
     */
    className?: string;
    /**
     * baloon header/arrow colour
     */
    color?: string;
    /**
     * baloon direction
     * 		bottom: the baloon will appear from bottom
     * 		top: the baloon will appear from top
     */
    direction?: string;
    /**
     * baloon title
     */
    title?: string;
    /**
     * flags if the baloon is visible or not
     */
    visible?: boolean;
  }

  interface IBaloonState {}

  export class Baloon extends React.Component<IBaloonProps, IBaloonState> {}
}

declare module "ride-components-react/components/buttons/button" {
  export interface IButtonProps {
    /**
     * if set to true, the button will span the full width of it's own container element
     * @type {boolean}
     */
    block?: boolean;
    /**
     * you can add every css class you want
     * @type {string}
     */
    className?: string;
    /**
     * This will add the related css colour class
     * 	available colours:
     * 		black
     *     blue
     *     gray
     *     green
     *     orange
     *     purple
     *     red
     *     white
     *     yellow
     * @type {string}
     */
    color?: string;
    /**
     * if set to true, the button will be hollow
     * @type {boolean}
     */
    hollow?: boolean;
    /**
     * if provided, the css button will have a glyphicon element with the provided className
     * @type {string}
     */
    icon?: string;
    /**
     * the onClick callback event
     * @type {any}
     */
    onClick?: any;
    /**
     * the onTouchEnd callback event
     * @type {any}
     */
    onTouchEnd?: any;
    /**
     * the onTouchStart callback event
     * @type {any}
     */
    onTouchStart?: any;
    /**
     * this will add a btn--rounded css class
     */
    rounded?: boolean;
    /**
     * button's title
     * @type {string}
     */
    title?: string;
  }

  export class Button extends React.Component<IButtonProps, {}> {}
}

declare module "ride-components-react/components/buttons/list" {
  import * as button from 'ride-components-react/components/buttons/button';
  import * as list from 'ride-components-react/components/lists/list';

  export interface IButtonListItemProps extends button.IButtonProps {
    current?: string;
  }

  export class ButtonListItem extends React.Component<IButtonListItemProps, {}> {}

  export class ButtonList extends React.Component<list.IListProperties, {}> {}
}

declare module "ride-components-react/components/cards/card" {
  export interface ICardHeaderProps {
    color?: string;
    className?: string;
    image?: string;
    tall?: boolean;
  }

  export interface ICardProps {
    afterContent?: any;
    beforeContent?: any;
    color?: string;
    footer?: any;
    hideHeader?: boolean;
    headerClassName?: string;
    headerImage?: string;
    headerTall?: boolean;
    title?: string;
  }

  export class CardHeader extends React.Component<ICardHeaderProps, {}> {}

  export class Card extends React.Component<ICardProps, {}> {}
}

declare module "ride-components-react/components/dialog/dialog" {
  export interface IDialogProps {
    closeIcon?: string;
    colour?: string;
    fullSize?: boolean;
    footer?: any;
    modal?: boolean;
    position: string;
    title: string;
    visible?: boolean;
  }

  export class Dialog extends React.Component<IDialogProps, {}> { }
}

declare module "ride-components-react/components/form" {
  export * from "ride-components-react/components/form/block";
  export * from "ride-components-react/components/form/checkbox";
  export * from "ride-components-react/components/form/range";
  export * from "ride-components-react/components/form/toggle";
}

declare module "ride-components-react/components/form/block" {
  export class Block extends React.Component<{}, {}> {}
}

declare module "ride-components-react/components/form/checkbox" {
  export interface ICheckboxProperties {
    checked?: boolean;
    color?: string;
    onChange: any;
    name?: string;
    type?: string;
    valueFalse?: any;
    valueTrue?: any;
  }

  export class Checkbox extends React.Component<ICheckboxProperties, {}> { }

  export class Radio extends Checkbox { }
}

declare module "ride-components-react/components/form/range" {
  export interface IFormRangeProps {
    color?: string;
    onChange?: any;
    value?: number;
  }

  export interface IFormRangeState { }

  export class Range extends React.Component<IFormRangeProps, IFormRangeState> { }
}

declare module "ride-components-react/components/form/toggle" {
  export interface IToggleProps {
    checked?: boolean;
    color?: string;
    onChange?: any;
  }

  export class Toggle extends React.Component<IToggleProps, {}> { }
}

declare module "ride-components-react/components/layout/col" {
  export interface IColProps {
    className?: string;
    offset?: IColBreakpoints;
    move?: IColBreakpoints;
    width?: IColBreakpoints;
  }

  export interface IColBreakpoints {
    xs?: number;
    sm?: number;
    md?: number;
    lg?: number;
    xl?: number;
  }

  export class Col extends React.Component<IColProps, {}> {}
}

declare module "ride-components-react/components/layout/row" {
  export interface IRowProps {

  }

  export class Row extends React.Component<IRowProps, {}> { }
}

declare module "ride-components-react/components/layout/wrapper" {
  export interface IWrapperProps {
    size?: string;
  }

  export class Wrapper extends React.Component<IWrapperProps, any> { }
}

declare module "ride-components-react/components/lists/list" {
  export interface IListItemProperties {
    current?: boolean;
    className?: string;
    hidden?: boolean;
  }

  export interface IListProperties {
    center?: boolean;
    className?: string;
    hidden?: boolean;
    indented?: boolean;
    unpadded?: boolean;
    vertical?: boolean;
  }

  export class ListItem extends React.Component<IListItemProperties, any> {}

  export class List extends React.Component<IListProperties, {}> {}
}

declare module "ride-components-react/components/notifications/alert" {
  export interface IAlertProps { }

  export class Alert extends React.Component<IAlertProps, {}> { }
}

declare module "ride-components-react/components/notifications/notification" {
  export interface INotificationProperties extends INotificationState {
    color?: string;
    hollow?: boolean;
    rounded?: boolean;
  }

  export interface INotificationState {
    hidden?: boolean;
  }

  export class Notification extends React.Component<INotificationProperties, INotificationState> { }
}

declare module "ride-components-react/components/notifications/popup" {
  export interface IPopupProps {
    color?: string;
    hidden?: boolean;
    modal?: boolean;
    rounded?: boolean;
    text?: string;
  }

  export class Popup extends React.Component<IPopupProps, {}> {}
}

declare module "ride-components-react/components/notifications/push-notifications" {
  export interface IPushNotificationsProps {
    position?: string;
    style?: React.CSSProperties;
  }

  export class PushNotifications extends React.Component<IPushNotificationsProps, any> {}
}

declare module "ride-components-react/components/tabs/tabs" {
  export interface ITabsProps {
    buttonColor?: string;
    buttonActiveColor?: string;
    buttons: Array<string>;
    hidden?: boolean;
    selected?: string;
    vertical?: boolean;
  }

  export interface ITabsState {
    current: string;
  }

  export class Tabs extends React.Component<ITabsProps, ITabsState> { }
}

declare module "ride-components-react/components/user/image" {
  export interface IUserImageProps {
    large?: boolean;
    src: string;
  }

  export class UserImage extends React.Component<IUserImageProps, {}> { }
}

declare module "ride-components-react/components/user/user" {
  export interface IUser {
    vSpace?: boolean;
  }

  export class User extends React.Component<IUser, {}> { }
}

declare module "ride-components-react/ui" {
  export * from "ride-components-react/components/baloons/baloon";
  export * from "ride-components-react/components/buttons/button";
  export * from "ride-components-react/components/buttons/list";
  export * from "ride-components-react/components/dialog/dialog";
  export * from "ride-components-react/components/cards/card";
  export * from "ride-components-react/components/layout/col";
  export * from "ride-components-react/components/layout/row";
  export * from "ride-components-react/components/layout/wrapper";
  export * from "ride-components-react/components/lists/list";
  export * from "ride-components-react/components/notifications/notification";
  export * from "ride-components-react/components/notifications/popup";
  export * from "ride-components-react/components/notifications/push-notifications";
  export * from "ride-components-react/components/tabs/tabs";
  export * from "ride-components-react/components/user/image";
  export * from "ride-components-react/components/user/user";
}

/**
 * CSS decls
 */
declare module "ride-components-react/css/app/css" {

}

declare module "ride-components-react/css/app/aside/css" {
  export namespace appAside {
    export const aside: string;
    export const black: string;
    export const blue: string;
    export const expanded: string;
    export const gray: string;
    export const green: string;
    export const orange: string;
    export const purple: string;
    export const red: string;
    export const yellow: string;
    export const white: string;
  }
}

declare module "ride-components-react/css/app/content/css" {
  export namespace appContent {
    export const content: string;
    export const black: string;
    export const blue: string;
    export const gray: string;
    export const green: string;
    export const orange: string;
    export const purple: string;
    export const red: string;
    export const yellow: string;
    export const white: string;
  }
}

declare module "ride-components-react/css/app/title/css" {
  export namespace appTitle {
    export const title: string;
    export const black: string;
    export const blue: string;
    export const gray: string;
    export const green: string;
    export const orange: string;
    export const purple: string;
    export const red: string;
    export const yellow: string;
    export const white: string;
  }
}

declare module "ride-components-react/css/app/toolbar/css" {
  export namespace appToolbar {
    export const toolbar: string;
    export const black: string;
    export const blue: string;
    export const gray: string;
    export const green: string;
    export const orange: string;
    export const purple: string;
    export const red: string;
    export const yellow: string;
    export const white: string;
  }
}

declare module "ride-components-react/css/baloon/css" {
  export namespace baloon {
    export const baloon: string;
    export const black: string;
    export const blue: string;
    export const bottom: string;
    export const gray: string;
    export const green: string;
    export const orange: string;
    export const purple: string;
    export const red: string;
    export const top: string;
    export const visible: string;
    export const white: string;
    export const yellow: string;
    export const baloon__content: string;
    export const baloon__header: string;
    export const baloon__triangle: string;
    export const baloonWrapper: string;
    export const baloonWrapperHover: string;
  }
}

declare module "ride-components-react/css/buttons/css" {
  export namespace btn {
    export const btn: string;
    export const black: string;
    export const block: string;
    export const blue: string;
    export const disabled: string;
    export const icon: string;
    export const gray: string;
    export const green: string;
    export const hollow: string;
    export const orange: string;
    export const purple: string;
    export const red: string;
    export const rounded: string;
    export const white: string;
    export const yellow: string;
  }
}

declare module "ride-components-react/css/cards/css" {
  export namespace card {
    export const card: string;
    export const content: string;
    export const footer: string;
    export namespace header {
      export const header: string;
      export const black: string;
      export const blue: string;
      export const gray: string;
      export const green: string;
      export const orange: string;
      export const purple: string;
      export const red: string;
      export const yellow: string;
      export const tall: string;
      export const unpadded: string;
      export const white: string;
    }
  }
}

declare module "ride-components-react/css/colours/css" {
  export namespace colours {
    export const black: string;
    export const blue: string;
    export const gray: string;
    export const green: string;
    export const orange: string;
    export const purple: string;
    export const red: string;
    export const yellow: string;
    export const white: string;
  }
}

declare module "ride-components-react/css/dialog/css" {
  export namespace dialog {
    export const dialog: string;
    export const fullSize: string;
    export const bottom: string;
    export const center: string;
    export const top: string;
    export const black: string;
    export const blue: string;
    export const gray: string;
    export const green: string;
    export const orange: string;
    export const purple: string;
    export const red: string;
    export const visible: string;
    export const yellow: string;
    export const dialog__content: string;
    export const dialog__footer: string;
    export const dialog__header: string;

    export namespace overlay {
      export const overlay: string;
      export const visible: string;
    }
  }
}

declare module "ride-components-react/css/form/css" {

}

declare module "ride-components-react/css/form/block/css" {
  export namespace block {
    export const block: string;
    export const inline: string;
    export const rounded__elements: string;
  }
}

declare module "ride-components-react/css/form/checkbox/css" {
  export namespace checkbox {
    export const checkbox: string;
    export const black: string;
    export const blue: string;
    export const gray: string;
    export const green: string;
    export const orange: string;
    export const purple: string;
    export const red: string;
    export const yellow: string;
  }
}

declare module "ride-components-react/css/form/radio/css" {
  export namespace radio {
    export const radio: string;
    export const black: string;
    export const blue: string;
    export const gray: string;
    export const green: string;
    export const orange: string;
    export const purple: string;
    export const red: string;
    export const yellow: string;
  }
}

declare module "ride-components-react/css/form/range/css" {
  export namespace range {
    export const black: string;
    export const blue: string;
    export const gray: string;
    export const green: string;
    export const orange: string;
    export const purple: string;
    export const range: string;
    export const red: string;
    export const yellow: string;
  }
}

declare module "ride-components-react/css/form/toggle/css" {
  export namespace toggle {
    export const toggle: string;
    export const black: string;
    export const blue: string;
    export const gray: string;
    export const green: string;
    export const orange: string;
    export const purple: string;
    export const red: string;
    export const yellow: string;
    export const text: string;
    export const toggle__toggle: string;
  }
}

declare module "ride-components-react/css/lists/css" {
  export namespace list {
    export const list: string;
    export const indented: string;
    export const vertical: string;
  }
}

declare module "ride-components-react/css/notifications/css" {

}

declare module "ride-components-react/css/notifications/notifications/css" {
  export namespace notification {
    export const notification: string;
    export const black: string;
    export const blue: string;
    export const gray: string;
    export const green: string;
    export const hidden: string;
    export const hollow: string;
    export const orange: string;
    export const purple: string;
    export const red: string;
    export const yellow: string;
    export const rounded: string;
  }
}

declare module "ride-components-react/css/notifications/popup/css" {
  export namespace popup {
    export const popup: string;
    export const black: string;
    export const blue: string;
    export const gray: string;
    export const green: string;
    export const hidden: string;
    export const modal: string;
    export const orange: string;
    export const purple: string;
    export const red: string;
    export const yellow: string;
    export const white: string;
    export const rounded: string;
    export const popup__text: string;
  }
}

declare module "ride-components-react/css/notifications/push-notifications/css" {
  export namespace pushNotifications {
    export const pushNotifications: string;
    export const bottomLeft: string;
    export const bottomRight: string;
    export const topLeft: string;
    export const topRight: string;
  }
}

declare module "ride-components-react/css/text/css" {

}

declare module "ride-components-react/css/text/align/css" {
  interface alignCenter {
    xs: string;
    sm: string;
    md: string;
    lg: string;
    xl: string;
  }
  interface alignLeft {
    xs: string;
    sm: string;
    md: string;
    lg: string;
    xl: string;
  }
  interface alignRight {
    xs: string;
    sm: string;
    md: string;
    lg: string;
    xl: string;
  }

  export namespace align {
    export const center: alignCenter;
    export const left: alignLeft;
    export const right: alignRight;
  }
}

declare module "ride-components-react/css/text/casing/css" {
  export namespace casing {
    export const capitalize: string;
    export const italic: string;
    export const lowercase: string;
    export const uppercase: string;
  }
}

declare module "ride-components-react/css/text/links/css" {
  export namespace links {
    export const black: string;
    export const blue: string;
    export const gray: string;
    export const green: string;
    export const orange: string;
    export const purple: string;
    export const red: string;
    export const white: string;
    export const yellow: string;
  }
}

declare module "ride-components-react/css/user/css" {

}

declare module "ride-components-react/css/user/image/css" {
  export namespace userImage {
    export const userImage: string;
    export const large: string;
    export const wrapper: string;
  }
}

declare module "ride-components-react/css/wrapper/css" {
  export namespace wrapper {
    export const tight: string;
    export const wide: string;
    export const wrapper: string;
  }
}

// declare module "ride-components-react/components/buttons/list" { }

/**
 * Utilities
 */
declare module "ride-components-react/utilities/css" {
  export class CssClassList {
    public add(className: string): CssClassList;
    public has(className: string): boolean;
    public remove(className: string): CssClassList;
    public toggle(className: string): CssClassList;
    public toString(): string;
  }
}

declare module "ride-components-react/utilities/dom" {
  export function get(selector: string): Element;
  export function getAll(selector: string): Array<Element>;
  export function ready(callback: any);
  export function renderComponent(component: any, target: string): Function;
}

declare module "ride-components-react/utilities/store" {
  export class Store<TStore> {
    private _data: TStore;
    private _history: Array<TStore>;
    private _initial: TStore;

    constructor(data: TStore);

    private _store(): void;
    private _storeRollback(): void;
    private _update(data: TStore);

    public clone(): Store<TStore>;
    public get(): TStore;
    public reset(): void;
    public rollback(): void;
    public update(data: TStore);
    public updateStrict(data: TStore);
  }
}



// declare module "ride-components-react/components/buttons/list" { }
